@@ -7,12 +7,12 @@ if [ _${SCRIPT}_ != _spruch_  -a _${SCRIPT}_ != _fortune_  ] ; then
   DB=/${SCRIPT}
 fi
 
-lang=$(locale | sed -ne 's/"$//;s/^LC_MESSAGES="\?//p')
+lang=$(locale  2>/dev/null | sed -ne 's/"$//;s/^LC_MESSAGES="\?//p')
 l=$(sed -ne "s/^$(echo $lang | sed 's/\(\.\|\^\|\$\|\*\|\[\)/\\\1/g')[ 	]\+//ip" /etc/locale.alias)
 [ -n "$l" ] && lang="$l"
 
 # check for the currently used charmap
-charmap=$(locale -k LC_CTYPE | sed -ne 's/^charmap="\([^"]*\)"$/\1/p')
+charmap=$(locale 2>/dev/null -k LC_CTYPE | sed -ne 's/^charmap="\([^"]*\)"$/\1/p')
 
 # if there are any parameters check for given file name
 found=0
